% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/community.R
\name{cluster_fluid_communities}
\alias{cluster_fluid_communities}
\title{Community detection algorithm based on interacting fluids}
\usage{
cluster_fluid_communities(graph, no.of.communities)
}
\arguments{
\item{graph}{The input graph. The graph must be simple and connected.
Empty graphs are not supported as well as single vertex graphs.
Edge directions are ignored. Weights are not considered.}

\item{no.of.communities}{The number of communities to be found. Must be
greater than 0 and fewer than number of vertices in the graph.}
}
\value{
\code{cluster_fluid_communities} returns a \code{\link{communities}}
object, please see the \code{\link{communities}} manual page for details.
}
\description{
The algorithm detects communities based on the simple idea of
several fluids interacting in a non-homogeneous environment
(the graph topology), expanding and contracting based on their
interaction and density.
}
\examples{
g <- graph.famous("Zachary")
comms <- cluster_fluid_communities(g, 2)
}
\references{
Parés F, Gasulla DG, et. al. (2018) Fluid Communities: A Competitive,
Scalable and Diverse Community Detection Algorithm. In: Complex Networks
&amp; Their Applications VI: Proceedings of Complex Networks 2017 (The Sixth
International Conference on Complex Networks and Their Applications),
Springer, vol 689, p 229, doi: 10.1007/978-3-319-72150-7_19
}
\seealso{
See \code{\link{communities}} for extracting the membership,
modularity scores, etc. from the results.

Other community detection algorithms: \code{\link{cluster_walktrap}},
\code{\link{cluster_spinglass}},
\code{\link{cluster_leading_eigen}},
\code{\link{cluster_edge_betweenness}},
\code{\link{cluster_fast_greedy}},
\code{\link{cluster_label_prop}}
\code{\link{cluster_louvain}},
\code{\link{cluster_leiden}}
}
\author{
Ferran Parés
}
\keyword{graphs}
