% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/centrality.R
\name{strength}
\alias{strength}
\alias{graph.strength}
\title{Strength or weighted vertex degree}
\usage{
strength(
  graph,
  vids = V(graph),
  mode = c("all", "out", "in", "total"),
  loops = TRUE,
  weights = NULL
)
}
\arguments{
\item{graph}{The input graph.}

\item{vids}{The vertices for which the strength will be calculated.}

\item{mode}{Character string, \dQuote{out} for out-degree, \dQuote{in} for
in-degree or \dQuote{all} for the sum of the two. For undirected graphs this
argument is ignored.}

\item{loops}{Logical; whether the loop edges are also counted.}

\item{weights}{Weight vector. If the graph has a \code{weight} edge
attribute, then this is used by default. If the graph does not have a
\code{weight} edge attribute and this argument is \code{NULL}, then a
warning is given and \code{\link{degree}} is called.}
}
\value{
A numeric vector giving the strength of the vertices.
}
\description{
Summing up the edge weights of the adjacent edges for each vertex.
}
\examples{

g <- make_star(10)
E(g)$weight <- seq(ecount(g))
strength(g)
strength(g, mode="out")
strength(g, mode="in")

# No weights, a warning is given
g <- make_ring(10)
strength(g)
}
\references{
Alain Barrat, Marc Barthelemy, Romualdo Pastor-Satorras,
Alessandro Vespignani: The architecture of complex weighted networks, Proc.
Natl. Acad. Sci. USA 101, 3747 (2004)
}
\seealso{
\code{\link{degree}} for the unweighted version.
}
\author{
Gabor Csardi \email{csardi.gabor@gmail.com}
}
\keyword{graphs}
